.. _frequencies:

**************************************************************
Frequency Plasma Parameters (`plasmapy.formulary.frequencies`)
**************************************************************

.. currentmodule:: plasmapy.formulary.frequencies

.. automodapi:: plasmapy.formulary.frequencies

Examples
========

.. nbgallery::
    :caption: Examples

    /notebooks/formulary/ExB_drift
    /notebooks/formulary/iter
